@@ -19,6 +19,6 @@ impl<'a, T> Iterator for MatrixIterator<'a, T>
 
     fn next(&mut self) -> Option<Self::Item>
     {
-        return self.iter.next();
+        self.iter.next()
     }
 }
