@@ -16,7 +16,7 @@ use std::{
     fmt,
     fmt::Display,
     iter::IntoIterator,
-    ops::{Neg, Mul},
+    ops::{Neg},
 };
 
 /// Macro to construct vectors
@@ -40,28 +40,16 @@ macro_rules! vector
     ($( $x: expr ),*) =>
     {
         {
-            let data = [ $($x),* ];
-            let rows = data.len();
-            let mut data_array: Vec<_> = Vec::with_capacity(rows);
-            for i in 0..rows
-            {
-                data_array.push(data[i]);
-            }
-            Vector::new_row(rows, data_array)
+            let data_array = vec![ $($x),* ];
+            Vector::new_row(data_array)
         }
     };
 
     ($( $x: expr );*) =>
     {
         {
-            let data = [ $($x),* ];
-            let cols = data.len();
-            let mut data_array: Vec<_> = Vec::with_capacity(cols);
-            for i in 0..cols
-            {
-                data_array.push(data[i]);
-            }
-            Vector::new_column(cols, data_array)
+            let data_array = vec![ $($x),* ];
+            Vector::new_column(data_array)
         }
     };
 }
@@ -121,7 +109,7 @@ impl<T> Vector<T> where T: Field + Scalar + Power
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![1.0, 0.0, 3.0, -2.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![1.0, 0.0, 3.0, -2.0]);
     /// let p: f64 = 2.0;
     /// let norm_ref: f64 = a.eucl_norm();
     /// let norm: f64 = a.p_norm(&p);
@@ -136,7 +124,7 @@ impl<T> Vector<T> where T: Field + Scalar + Power
         let mut sum: T = T::zero();
         for i in 0..(m * n)
         {
-            let b: T = *self.get(i);
+            let b: T = self[i];
             sum += b.pow(*p);
         }
         let norm: T = sum.pow(T::one() / *p);
@@ -150,7 +138,7 @@ impl<T> Neg for Vector<T> where T: Field + Scalar
 
     fn neg(self: Self) -> Self::Output
     {
-        return self.apply(&|&x| -x);
+        self.apply(&|&x| -x)
     }
 }
 
@@ -158,11 +146,12 @@ impl<T> Vector<T>
 {
     pub fn convert_to_vec(self: Self) -> Vec<T>
     {
-        return self.data.convert_to_vec();
+        self.data.convert_to_vec()
     }
 }
 
-impl<T> Vector<T> where T: Field + Scalar + Power + Exponential
+impl<T> Vector<T>
+    where T: Field + Scalar + Power + Exponential
 {
     /// Computes the euclidean norm
     ///
@@ -171,7 +160,7 @@ impl<T> Vector<T> where T: Field + Scalar + Power + Exponential
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![1.0, 0.0, 3.0, -2.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![1.0, 0.0, 3.0, -2.0]);
     /// let norm_ref: f64 = 3.7416573867739413;
     /// let norm: f64 = a.eucl_norm();
     ///
@@ -181,7 +170,7 @@ impl<T> Vector<T> where T: Field + Scalar + Power + Exponential
     {
         let exp: T = T::from_f64(2.0);
 
-        return self.p_norm(&exp);
+        self.p_norm(&exp)
     }
 }
 
@@ -189,40 +178,30 @@ impl<T> Vector<T> where T: Clone + Copy
 {
     /// Returns a row vector
     ///
-    /// # Panics
-    ///
-    /// n != data.len()
-    ///
     /// # Example
     ///
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_row(4, vec![1.0, 0.0, 3.0, -2.0]);
+    /// let a: Vector<f64> = Vector::new_row(vec![1.0, 0.0, 3.0, -2.0]);
     /// ```
-    pub fn new_row(n: usize, data: Vec<T>) -> Self
+    pub fn new_row(data: Vec<T>) -> Self
     {
-        assert_eq!(n, data.len());
-        Vector { data: Matrix::new(1, n, data) }
+        Vector { data: Matrix::new(1, data.len(), data) }
     }
 
     /// Returns a column vector
     ///
-    /// # Panics
-    ///
-    /// m != data.len()
-    ///
     /// # Example
     ///
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![1.0, 0.0, 3.0, -2.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![1.0, 0.0, 3.0, -2.0]);
     /// ```
-    pub fn new_column(m: usize, data: Vec<T>) -> Self
+    pub fn new_column(data: Vec<T>) -> Self
     {
-        assert_eq!(m, data.len());
-        Vector { data: Matrix::new(m, 1, data) }
+        Vector { data: Matrix::new(data.len(), 1, data) }
     }
 
     pub fn apply(mut self: Vector<T>, f: &dyn Fn(&T) -> T) -> Self
@@ -263,24 +242,24 @@ impl<T> Vector<T> where T: Scalar
     }
 }
 
-impl<T> Vector<T> where T: Field + Scalar
+impl<T> Vector<T>
+    where T: Field + Scalar
 {
     /// Returns the transposed vector
     ///
-    ///
     /// # Example
     ///
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![1.0, 0.0, 3.0, -2.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![1.0, 0.0, 3.0, -2.0]);
     /// let b: Vector<f64> = a.transpose();
     /// ```
     pub fn transpose(mut self: Self) -> Self
     {
         self.data = self.data.transpose();
 
-        return self;
+        self
     }
 }
 
@@ -289,33 +268,32 @@ impl<T> Vector<T>
 {
     /// Computes the dot product of two vectors
     ///
-    ///
     /// # Example
     ///
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![1.0, 0.0, 3.0, -2.0]);
-    /// let b: Vector<f64> = Vector::new_column(4, vec![-1.0, 2.0, 3.0, 5.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![1.0, 0.0, 3.0, -2.0]);
+    /// let b: Vector<f64> = Vector::new_column(vec![-1.0, 2.0, 3.0, 5.0]);
     /// let dotp_ref: f64 = -2.0;
     ///
     /// let dotp: f64 = a.dotp(&b);
     ///
     /// assert_eq!(dotp_ref, dotp);
     /// ```
-    pub fn dotp<'a, 'b>(self: &'a Self, rhs: &'b Self) -> T
+    pub fn dotp(self: &Self, rhs: &Self) -> T
     {
         let (lhs_m, lhs_n) = self.dim();
         let (rhs_m, rhs_n) = rhs.dim();
-        assert!(lhs_m != 0);
-        assert!(lhs_n == 1);
+        assert_ne!(lhs_m, 0);
+        assert_eq!(lhs_n, 1);
         assert_eq!(lhs_m, rhs_m);
         assert_eq!(lhs_n, rhs_n);
 
         let temp: Vector<T> = self.clone().transpose();
-        let res: Matrix<T> = (&temp.data).mul(&(rhs.data));
+        let res: Matrix<T> = &temp.data * &rhs.data;
 
-        return (*res.get(0, 0)).clone();
+        res[[0, 0]]
     }
 
     /// Find the argmax of the vector.
@@ -327,7 +305,7 @@ impl<T> Vector<T>
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a = Vector::new_column(4, vec![1.0, 2.0, -3.0, 5.0]);
+    /// let a = Vector::new_column(vec![1.0, 2.0, -3.0, 5.0]);
     /// let idx = a.argmax();
     /// assert_eq!(idx, 3);
     /// ```
@@ -336,15 +314,15 @@ impl<T> Vector<T>
         let (m, n) = self.dim();
 
         let mut max_index: usize = 0;
-        let mut max = *self.get(max_index);
+        let mut max = self[max_index];
 
         let limit: usize = m.max(n);
 
-        assert!(limit != 0);
+        assert_ne!(limit, 0);
 
         for idx in 0..limit
         {
-            let element: T = *self.get(idx);
+            let element: T = self[idx];
             if element > max
             {
                 max_index = idx;
@@ -352,7 +330,7 @@ impl<T> Vector<T>
             }
         }
 
-        return max_index;
+        max_index
     }
 
     /// Find the argmin of the vector.
@@ -364,7 +342,7 @@ impl<T> Vector<T>
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a = Vector::new_column(4, vec![1.0, -2.0, -6.0, 75.0]);
+    /// let a = Vector::new_column(vec![1.0, -2.0, -6.0, 75.0]);
     /// let b = a.argmin();
     /// assert_eq!(b, 2);
     /// ```
@@ -373,15 +351,15 @@ impl<T> Vector<T>
         let (m, n) = self.dim();
 
         let mut min_index: usize = 0;
-        let mut min: T = *self.get(min_index);
+        let mut min: T = self[min_index];
 
         let limit: usize = m.max(n);
 
-        assert!(limit != 0);
+        assert_ne!(limit, 0);
 
         for idx in 0..limit
         {
-            let element: T = *self.get(idx);
+            let element: T = self[idx];
             if element < min
             {
                 min_index = idx;
@@ -389,7 +367,7 @@ impl<T> Vector<T>
             }
         }
 
-        return min_index;
+        min_index
     }
 }
 
@@ -403,8 +381,8 @@ impl<T> Vector<T>
     /// ```
     /// use mathru::algebra::linear::{Matrix, Vector};
     ///
-    /// let a: Vector<f64> = Vector::new_row(4, vec![1.0, 0.0, 3.0, -2.0]);
-    /// let b: Vector<f64> = Vector::new_column(4, vec![-1.0, 2.0, 3.0, 5.0]);
+    /// let a: Vector<f64> = Vector::new_row(vec![1.0, 0.0, 3.0, -2.0]);
+    /// let b: Vector<f64> = Vector::new_column(vec![-1.0, 2.0, 3.0, 5.0]);
     ///
     /// let m: Matrix<f64> = a.dyadp(&b);
     /// ```
@@ -418,91 +396,13 @@ impl<T> Vector<T>
         {
             for j in 0..y_m
             {
-                *c.get_mut(i, j) = self.get(i).clone() * rhs.get(j).clone();
+                c[[i, j]] = self[i].clone() * rhs[j];
             }
         }
         c
     }
 }
 
-impl<T> Vector<T>
-//where T: One + Zero
-{
-    /// Returns the mutual component
-    ///
-    /// # Arguments
-    ///
-    /// # Panics
-    ///
-    /// if i out of bounds
-    ///
-    /// # Example
-    ///
-    /// ```
-    /// use mathru::algebra::linear::Vector;
-    ///
-    /// let mut a: Vector<f64> = Vector::new_row(4, vec![1.0, 0.0, 3.0, -2.0]);
-    ///
-    /// *a.get_mut(1) = -4.0;
-    /// ```
-    pub fn get_mut(self: &mut Self, i: usize) -> &mut T
-    {
-        let (m, n): (usize, usize) = self.data.dim();
-        assert!(m == 1 || n == 1);
-
-        if m == 1
-        {
-            //row vector
-            assert!(i < n);
-            self.data.get_mut(0, i)
-        }
-        else
-        {
-            //column vector
-            assert!(i < m);
-            self.data.get_mut(i, 0)
-        }
-    }
-}
-
-impl<T> Vector<T>
-//where T: One + Zero
-{
-    /// Returns the component
-    ///
-    /// # Panics
-    ///
-    /// if i out of bounds
-    ///
-    /// # Example
-    ///
-    /// ```
-    /// use mathru::algebra::linear::Vector;
-    ///
-    /// let mut a: Vector<f64> = Vector::new_row(4, vec![1.0, 0.0, 3.0, -2.0]);
-    ///
-    /// assert_eq!(-2.0, *a.get_mut(3))
-    /// ```
-    pub fn get(self: &Self, i: usize) -> &T
-    {
-        let (m, n): (usize, usize) = self.data.dim();
-        assert!(m == 1 || n == 1);
-
-        if m == 1
-        {
-            //row vector
-            assert!(i < n);
-            self.data.get(0, i)
-        }
-        else
-        {
-            //column vector
-            assert!(i < m);
-            self.data.get(i, 0)
-        }
-    }
-}
-
 impl<T> Vector<T>
     where T: Field + Scalar + Power
 {
@@ -513,9 +413,9 @@ impl<T> Vector<T>
 
         let norm_x: T = self.p_norm(&two);
 
-        *x_temp.get_mut(0) += self.get(0).sign() * norm_x;
+        x_temp[0] += self[0].sign() * norm_x;
         let x_temp_norm: T = x_temp.p_norm(&two);
-        *x_temp.get_mut(0) /= x_temp_norm;
+        x_temp[0] /= x_temp_norm;
 
         x_temp
     }
@@ -531,7 +431,7 @@ impl<T> Vector<T>
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![0.0, 0.0, 0.0, 0.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![0.0, 0.0, 0.0, 0.0]);
     /// let b: Vector<f64> = Vector::zero(4);
     ///
     /// assert_eq!(a, b)
@@ -552,7 +452,7 @@ impl<T> Vector<T>
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![1.0, 1.0, 1.0, 1.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![1.0, 1.0, 1.0, 1.0]);
     /// let b: Vector<f64> = Vector::one(4);
     ///
     /// assert_eq!(a, b)
@@ -566,7 +466,7 @@ impl<T> Vector<T>
             vec.push(T::one());
         }
 
-        return Vector::new_column(m, vec);
+        Vector::new_column(vec)
     }
 }
 
@@ -579,7 +479,7 @@ impl<T> Vector<T>
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![1.0, 2.0, 3.0, 4.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![1.0, 2.0, 3.0, 4.0]);
     /// let (m, n): (usize, usize) = a.dim();
     /// assert_eq!(4, m);
     /// assert_eq!(1, n);
@@ -612,10 +512,10 @@ impl<T> Vector<T>
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let mut a: Vector<f64> = Vector::new_column(4, vec![1.0, -2.0, 3.0, -7.0]);
+    /// let mut a: Vector<f64> = Vector::new_column(vec![1.0, -2.0, 3.0, -7.0]);
     /// a = a.get_slice(1, 2);
     ///
-    /// let a_ref: Vector<f64> = Vector::new_column(2, vec![-2.0, 3.0]);
+    /// let a_ref: Vector<f64> = Vector::new_column(vec![-2.0, 3.0]);
     ///
     /// assert_eq!(a_ref, a);
     /// ```
@@ -637,10 +537,10 @@ impl<T> Vector<T>
 
         for r in s..(e + 1)
         {
-            *slice.get_mut(r - s) = *self.get(r)
+            slice[r - s] = self[r]
         }
 
-        return slice;
+        slice
     }
 
     /// Overwrite a slice of the vector with the given values
@@ -656,15 +556,15 @@ impl<T> Vector<T>
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let mut a: Vector<f64> = Vector::new_column(4, vec![1.0, -2.0, 3.0, -7.0]);
-    /// let b: Vector<f64> = Vector::new_column(2, vec![-5.0, 4.0]);
+    /// let mut a: Vector<f64> = Vector::new_column(vec![1.0, -2.0, 3.0, -7.0]);
+    /// let b: Vector<f64> = Vector::new_column(vec![-5.0, 4.0]);
     /// a.set_slice(&b, 1);
     ///
-    /// let a_ref: Vector<f64> = Vector::new_column(4, vec![1.0, -5.0, 4.0, -7.0]);
+    /// let a_ref: Vector<f64> = Vector::new_column(vec![1.0, -5.0, 4.0, -7.0]);
     ///
     /// assert_eq!(a_ref, a);
     /// ```
-    pub fn set_slice<'a>(self: &mut Self, rhs: &Self, s: usize)
+    pub fn set_slice(self: &mut Self, rhs: &Self, s: usize)
     {
         let (m, _n): (usize, usize) = self.dim();
         let (s_m, _s_n): (usize, usize) = rhs.dim();
@@ -672,7 +572,7 @@ impl<T> Vector<T>
 
         for r in s..(s + s_m)
         {
-            *self.get_mut(r) = *rhs.get(r - s);
+            self[r] = rhs[r - s];
         }
     }
 }
@@ -686,7 +586,7 @@ impl<T> PartialEq<Self> for Vector<T> where T: Scalar
     /// ```
     /// use mathru::algebra::linear::Vector;
     ///
-    /// let a: Vector<f64> = Vector::new_column(4, vec![0.0, 0.0, 0.0, 0.0]);
+    /// let a: Vector<f64> = Vector::new_column(vec![0.0, 0.0, 0.0, 0.0]);
     /// let b: Vector<f64> = Vector::zero(4);
     ///
     /// assert_eq!(true, a.eq(&b))
@@ -714,12 +614,12 @@ impl<T> Sign for Vector<T> where T: Field + Scalar
 {
     fn sign(self: &Self) -> Self
     {
-        return (self.clone()).apply(&|x: &T| x.sign());
+        (self.clone()).apply(&|x: &T| x.sign())
     }
 
     fn abs(self: &Self) -> Self
     {
-        return (self.clone()).apply(&|x: &T| x.abs());
+        (self.clone()).apply(&|x: &T| x.abs())
     }
 
     fn is_positive(self: &Self) -> bool
@@ -745,7 +645,7 @@ impl<T> AbsDiffEq for Vector<T>
 
     fn abs_diff_eq(&self, other: &Vector<T>, epsilon: T) -> bool
     {
-        return self.data.abs_diff_eq(&other.data, epsilon);
+        self.data.abs_diff_eq(&other.data, epsilon)
     }
 }
 
@@ -761,7 +661,7 @@ impl<T> RelativeEq for Vector<T>
     /// A test for equality that uses a relative comparison if the values are far apart.
     fn relative_eq(&self, other: &Vector<T>, epsilon: Self::Epsilon, max_relative: Self::Epsilon) -> bool
     {
-        return self.data.relative_eq(&other.data, epsilon, max_relative);
+        self.data.relative_eq(&other.data, epsilon, max_relative)
     }
 }
 
