@@ -23,6 +23,6 @@ impl<T> Iterator for VectorIntoIterator<T> where T: Field + Scalar
 
     fn next(self: &mut Self) -> Option<Self::Item>
     {
-        return self.iter.next();
+        self.iter.next()
     }
 }
