@@ -11,7 +11,7 @@ use serde::{Deserialize, Serialize};
 
 /// Solves an ODE using Ralston3's 3nd order method.
 ///
-/// <a href="https://en.wikipedia.org/wiki/List_of_Runge-Kutta_methods">https://en.wikipedia.org/wiki/List_of_Runge-Kutta_methods</a>
+/// <https://en.wikipedia.org/wiki/List_of_Runge-Kutta_methods>
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[derive(Clone, Debug)]
 pub struct Ralston3<T>
@@ -28,9 +28,9 @@ impl<T> Default for Ralston3<T> where T: Real
         let b: Vec<T> = vec![T::from_f64(2.0/9.0), T::from_f64(1.0/3.0), T::from_f64(4.0/9.0)];
         let c: Vec<T> = vec![T::from_f64(1.0/2.0), T::from_f64(3.0/4.0)];
 
-        return Ralston3 {
+        Ralston3 {
             butcher: ButcherFixedStepSize::new(a, b, c)
-        };
+        }
     }
 }
 
@@ -39,12 +39,12 @@ impl<T> ExplicitMethod<T> for Ralston3<T> where T: Real
     fn do_step<F>(self: &Self, prob: &F, t_n: &T, x_n: &Vector<T>, h: &T) -> Vector<T>
         where F: ExplicitODE<T>
     {
-        return self.butcher.do_step(prob, t_n, x_n, h);
+        self.butcher.do_step(prob, t_n, x_n, h)
     }
 
     // Ralston3's method is a 3rd order method
     fn order(self: &Self) -> u8
     {
-        return 3;
+        3
     }
 }
